Learn R Programming

dynfrail (version 0.5.2)

dynfrail_dist: Distribution parameters for dynfrail

Description

Distribution parameters for dynfrail

Usage

dynfrail_dist(dist = "gamma", theta = 2, pvfm = -1/2, lambda = 0.1,
  n_ints = NULL, times = NULL)

Arguments

dist

One of 'gamma', 'stable' or 'pvf'.

theta

Frailty distribution parameter. Must be >0.

pvfm

Only relevant if dist = 'pvf' is used. It determines which PVF distribution should be used. Must be larger than -1 and not equal to 0.

lambda

Frailty autocorrelation parameter. Must be >0.

n_ints

For piece-wise constant frailty, the number of intervals. With n_ints = 0, the classical shared frailty scenario is obtained.

times

A vector of time points which determine the piecewise-constant interval for the frailty. Overrides n_ints.

Value

An object of the type dynfrail_dist, which is mostly used to denote the supported frailty distributions in a consistent way.

Details

The theta and lambda arguments must be positive. In the case of gamma or PVF, theta is the inverse of the frailty variance, i.e. the larger the theta is, the closer the model is to a Cox model. When dist = "pvf" and pvfm = -0.5, the inverse Gaussian distribution is obtained. For the positive stable distribution, the \(\gamma\) parameter of the Laplace transform is \(\theta / (1 + \theta)\), with the \(alpha\) parameter fixed to 1.

See Also

dynfrail, dynfrail_control

Examples

Run this code
# NOT RUN {
dynfrail_dist()
# Compound Poisson distribution:
dynfrail_dist(dist = 'pvf', theta = 1.5, pvfm = 0.5)
# Inverse Gaussian distribution:
dynfrail_dist(dist = 'pvf')
# }

Run the code above in your browser using DataLab