Only relevant if dist = 'pvf' is used. It determines which PVF distribution should be used. Must be larger than -1 and not equal to 0.
lambda
Frailty autocorrelation parameter. Must be >0.
n_ints
For piece-wise constant frailty, the number of intervals. With n_ints = 0, the classical shared frailty scenario is obtained.
times
A vector of time points which determine the piecewise-constant interval for the frailty. Overrides n_ints.
Value
An object of the type dynfrail_dist, which is mostly used to denote the
supported frailty distributions in a consistent way.
Details
The theta and lambda arguments must be positive. In the case of gamma or PVF, theta is the inverse of
the frailty variance, i.e. the larger the theta is,
the closer the model is to a Cox model. When dist = "pvf" and pvfm = -0.5, the inverse Gaussian
distribution is obtained.
For the positive stable distribution, the \(\gamma\) parameter of the Laplace transform is
\(\theta / (1 + \theta)\), with the \(alpha\) parameter fixed to 1.